icsemantic.catalog.criteria.synonym

Package platecom :: Package ontocatalog :: Package criteria :: Module synonym |
[hide private]
[frames] | no frames]

# Source Code for Module icsemantic.catalog.criteria.synonym

     1  """A friendly criterion for ATTopic that matches the
     2  SearchableSynonymousText index parameters.
     3  """
     4
     5  from Products.CMFCore.permissions import View
     6  from AccessControl import ClassSecurityInfo
     7
     8  from Products.ATContentTypes.criteria import registerCriterion
     9  from Products.ATContentTypes.interfaces import IATTopicSearchCriterion
    10  from Products.ATContentTypes.permission import ChangeTopics
    11  from Products.ATContentTypes.criteria.simplestring import \
    12      ATSimpleStringCriterion
    13  from Products.ATContentTypes.criteria.simplestring import \
    14      ATSimpleStringCriterionSchema
    15
    16  from platecom.ontocatalog import OntoCatalogMessageFactory as _
    17
    18  ATSynonymCriterionSchema = ATSimpleStringCriterionSchema
    19
    20
    21 -class ATSynonymCriterion(ATSimpleStringCriterion):
    22      """A synonym text criterion"""
    23
    24      __implements__ = ATSimpleStringCriterion.__implements__ + \
    25                       (IATTopicSearchCriterion,)
    26
    27      security       = ClassSecurityInfo()
    28      schema         = ATSynonymCriterionSchema
    29      meta_type      = 'ATSynonymCriterion'
    30      archetype_name = 'Friendly Synonym Criterion'
    31      shortDesc      = 'Synonym Criterion'
    32
    33
    34  registerCriterion(ATSynonymCriterion, ['SynonymIndex'])
    35